==> jc-1.4.0.tar.gz: javax/rmi/CORBA/ClassDesc.h <==
// public class javax.rmi.CORBA.ClassDesc

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6e5faeb66c21e60f javax_rmi_CORBA_ClassDesc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_CORBA_ClassDesc_H_
#define _JC_javax_rmi_CORBA_ClassDesc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_ClassDesc$sub_refs	_jc_javax_rmi_CORBA_ClassDesc$sub_refs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs	_jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$refs	_jc_javax_rmi_CORBA_ClassDesc$refs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$nonrefs	_jc_javax_rmi_CORBA_ClassDesc$nonrefs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$object	_jc_javax_rmi_CORBA_ClassDesc$object;

typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vmethods	_jc_javax_rmi_CORBA_ClassDesc$vmethods;
typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vtable	_jc_javax_rmi_CORBA_ClassDesc$vtable;
typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vtype	_jc_javax_rmi_CORBA_ClassDesc$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_ClassDesc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_ClassDesc$object *);

// Virtual methods structure
struct _jc_javax_rmi_CORBA_ClassDesc$vmethods {
};

// Vtable
struct _jc_javax_rmi_CORBA_ClassDesc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ClassDesc$vmethods	javax_rmi_CORBA_ClassDesc;
};

// Vtype
struct _jc_javax_rmi_CORBA_ClassDesc$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_ClassDesc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ClassDesc$sub_refs {
	struct _jc_java_lang_String$object	*repid;
	struct _jc_java_lang_String$object	*codebase;
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_ClassDesc$refs {
    _jc_javax_rmi_CORBA_ClassDesc$sub_refs	javax_rmi_CORBA_ClassDesc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_ClassDesc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs	javax_rmi_CORBA_ClassDesc;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_ClassDesc$object {
	_jc_javax_rmi_CORBA_ClassDesc$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_ClassDesc$vtype	*vtype;
	_jc_javax_rmi_CORBA_ClassDesc$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_ClassDesc$vtype _jc_javax_rmi_CORBA_ClassDesc$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_ClassDesc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_ClassDesc$class_object;

#endif	/* _JC_javax_rmi_CORBA_ClassDesc_H_ */

==> jc-1.4.6.tar.gz: javax/rmi/CORBA/ClassDesc.h <==
// public class javax.rmi.CORBA.ClassDesc

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6e5faeb66c21e60f javax_rmi_CORBA_ClassDesc

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_rmi_CORBA_ClassDesc_H_
#define _JC_javax_rmi_CORBA_ClassDesc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_rmi_CORBA_ClassDesc$sub_refs	_jc_javax_rmi_CORBA_ClassDesc$sub_refs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs	_jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$refs	_jc_javax_rmi_CORBA_ClassDesc$refs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$nonrefs	_jc_javax_rmi_CORBA_ClassDesc$nonrefs;
typedef struct _jc_javax_rmi_CORBA_ClassDesc$object	_jc_javax_rmi_CORBA_ClassDesc$object;

typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vmethods	_jc_javax_rmi_CORBA_ClassDesc$vmethods;
typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vtable	_jc_javax_rmi_CORBA_ClassDesc$vtable;
typedef const struct _jc_javax_rmi_CORBA_ClassDesc$vtype	_jc_javax_rmi_CORBA_ClassDesc$vtype;

// Constructors
extern void _jc_javax_rmi_CORBA_ClassDesc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_rmi_CORBA_ClassDesc$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_rmi_CORBA_ClassDesc$vmethods {
};

// Vtable
struct _jc_javax_rmi_CORBA_ClassDesc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_rmi_CORBA_ClassDesc$vmethods	javax_rmi_CORBA_ClassDesc;
};

// Vtype
struct _jc_javax_rmi_CORBA_ClassDesc$vtype {
	_jc_type			type;
	_jc_javax_rmi_CORBA_ClassDesc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ClassDesc$sub_refs {
	struct _jc_java_lang_String$object	*repid;
	struct _jc_java_lang_String$object	*codebase;
};

// Reference instance fields (object)
struct _jc_javax_rmi_CORBA_ClassDesc$refs {
    _jc_javax_rmi_CORBA_ClassDesc$sub_refs	javax_rmi_CORBA_ClassDesc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_rmi_CORBA_ClassDesc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_rmi_CORBA_ClassDesc$sub_nonrefs	javax_rmi_CORBA_ClassDesc;
};

// Object instance structure
struct _jc_javax_rmi_CORBA_ClassDesc$object {
	_jc_javax_rmi_CORBA_ClassDesc$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_rmi_CORBA_ClassDesc$vtype	*vtype;
	_jc_javax_rmi_CORBA_ClassDesc$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_rmi_CORBA_ClassDesc$vtype _jc_javax_rmi_CORBA_ClassDesc$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_rmi_CORBA_ClassDesc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_rmi_CORBA_ClassDesc$class_object;

#endif	/* _JC_javax_rmi_CORBA_ClassDesc_H_ */
